# eric7.Plugins.DocumentationPlugins.Ericdoc.EricdocExecDialog

Module implementing a dialog to show the output of the ericdoc process.

### Global Attributes

None

### Classes

EricdocExecDialog | Class implementing a dialog to show the output of the ericdoc process.

### Functions

None

## EricdocExecDialog

Class implementing a dialog to show the output of the ericdoc process.

This class starts a QProcess and displays a dialog that shows the output of the documentation command process.

### Signals

processFinished()
  emitted to indicate the eric7_doc process finished

### Derived from

QDialog, Ui_EricdocExecDialog

### Class Attributes

None

### Class Methods

None

### Methods

EricdocExecDialog | Constructor
__finish | Private slot called when the process finished.
__readStderr | Private slot to handle the readyReadStandardError signal.
__readStdout | Private slot to handle the readyReadStandardOutput signal.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
start | Public slot to start the ericdoc command.

### Static Methods

None

#### EricdocExecDialog (Constructor)

EricdocExecDialog(cmdname, parent=None)

Constructor

cmdname (str)
  name of the documentation generator
parent (QWidget)
  parent widget of this dialog

#### EricdocExecDialog.__finish

__finish()

Private slot called when the process finished.

It is called when the process finished or the user pressed the button.

#### EricdocExecDialog.__readStderr

__readStderr()

Private slot to handle the readyReadStandardError signal.

It reads the error output of the process and inserts it into the error pane.

#### EricdocExecDialog.__readStdout

__readStdout()

Private slot to handle the readyReadStandardOutput signal.

It reads the output of the process, formats it and inserts it into the contents pane.

#### EricdocExecDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### EricdocExecDialog.start

start(args, fn)

Public slot to start the ericdoc command.

args (list of str)
  commandline arguments for ericdoc program
fn (str)
  filename or dirname to be processed by ericdoc program

Return:
  flag indicating the successful start of the process

Return Type:
  bool

Up